@@ -1,4 +1,4 @@
-package SchemaUserDepartmentPermission;
+package SchemaForThesisDocumentation;
 
 use Moose;
 #use MooseX::MarkAsMethods autoclean => 1;
